utils

package
v0.0.0-...-8fbfd88 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 17, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseConfType

func ParseConfType(s string, start int) types.ConfType

func ReadByte

func ReadByte(r io.Reader) (byte, error)

Read a single byte from an io.Reader

func ReadDelimitedList

func ReadDelimitedList(start, end byte, r io.Reader) (string, error)

Read from a stream until we've read a full delimited list, then return a string that is composed of the read bytes. If the start is sent in as 0, we skip matching the start. On error, simply return what's been read so far and the error seen

func ReadUInt32FromString

func ReadUInt32FromString(s string, start int) (uint32, int)

Types

This section is empty.

Jump to