Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReadDelimitedList ¶
Read from a stream until we've read a full delimited list, then return a string that is composed of the read bytes. If the start is sent in as 0, we skip matching the start. On error, simply return what's been read so far and the error seen
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.